@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -125,16 +125,16 @@ ok_error_t BinaryParser::init_and_parse() {
   }
   const auto type = static_cast<MACHO_TYPES>(*stream_->peek<uint32_t>());
 
-  is64_ = type == MACHO_TYPES::MH_MAGIC_64 ||
-          type == MACHO_TYPES::MH_CIGAM_64 ||
+  is64_ = type == MACHO_TYPES::MAGIC_64 ||
+          type == MACHO_TYPES::CIGAM_64 ||
           type == MACHO_TYPES::NEURAL_MODEL;
 
   binary_->is64_ = is64_;
   type_          = type;
   binary_->original_size_ = stream_->size();
 
-  bool should_swap = type == MACHO_TYPES::MH_CIGAM_64 ||
-                     type == MACHO_TYPES::MH_CIGAM;
+  bool should_swap = type == MACHO_TYPES::CIGAM_64 ||
+                     type == MACHO_TYPES::CIGAM;
 
   stream_->set_endian_swap(should_swap);
 
@@ -153,6 +153,15 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
     return make_error_code(lief_errors::read_error);
   }
 
+  // Pre-populate the symbol cache to avoid O(n) searches for each export
+  if (memoized_symbols_.empty()) {
+    for (const std::unique_ptr<LIEF::MachO::Symbol>& sym : binary_->symbols_) {
+      if (const std::string& name = sym->name(); !name.empty()) {
+        memoized_symbols_[name] = sym.get();
+      }
+    }
+  }
+
   const auto terminal_size = stream.read<uint8_t>();
   if (!terminal_size) {
     LIEF_ERR("Can't read terminal size");
@@ -177,7 +186,8 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
     if (search != memoized_symbols_.end()) {
       symbol = search->second;
     } else {
-      symbol = binary_->get_symbol(symbol_name);
+      LIEF_DEBUG("Cache miss for symbol: {}", symbol_name);
+      symbol = nullptr;
     }
     if (symbol != nullptr) {
       export_info->symbol_ = symbol;
@@ -195,6 +205,7 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
       // Weak bind of the pointer
       symbol->export_info_       = export_info.get();
       export_info->symbol_       = symbol.get();
+      memoized_symbols_[symbol_name] = symbol.get();
       binary_->symbols_.push_back(std::move(symbol));
     }
 
@@ -226,7 +237,8 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
       if (search != memoized_symbols_.end()) {
         symbol = search->second;
       } else {
-        symbol = binary_->get_symbol(imported_name);
+        LIEF_DEBUG("Cache miss for symbol: {}", imported_name);
+        symbol = nullptr;
       }
       if (symbol != nullptr) {
         export_info->alias_  = symbol;
@@ -244,6 +256,7 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
         // Weak bind of the pointer
         symbol->export_info_      = export_info.get();
         export_info->alias_       = symbol.get();
+        memoized_symbols_[symbol_name] = symbol.get();
         binary_->symbols_.push_back(std::move(symbol));
       }
 
@@ -283,6 +296,7 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
     LIEF_ERR("Can't read nb_children");
     return make_error_code(lief_errors::parsing_error);
   }
+
   for (size_t i = 0; i < *nb_children; ++i) {
     auto suffix = stream.read_string();
     if (!suffix) {
@@ -310,6 +324,7 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
     }
 
     if (!visited_.insert(child_node_offet).second) {
+      LIEF_DEBUG("Cycle detected in export trie at offset 0x{:x}", child_node_offet);
       break;
     }
 
@@ -318,6 +333,7 @@ ok_error_t BinaryParser::parse_export_trie(exports_list_t& exports,
       parse_export_trie(exports, *scoped, start, name, invalid_names);
     }
   }
+
   return ok();
 }
 
